changeset 12875:33a7a6329aa5

Changed references to vc-top-version into vc-master-workfile-version.
author André Spiegel <spiegel@gnu.org>
date Thu, 17 Aug 1995 13:50:33 +0000
parents 3afd71d56015
children fedbe59f374e
files lisp/vc.el
diffstat 1 files changed, 3 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/vc.el	Thu Aug 17 13:29:31 1995 +0000
+++ b/lisp/vc.el	Thu Aug 17 13:50:33 1995 +0000
@@ -224,7 +224,7 @@
      (progn   ;; RCS
        (vc-file-setprop file 'vc-default-branch nil)
        (vc-file-setprop file 'vc-head-version nil)
-       (vc-file-setprop file 'vc-top-version nil)
+       (vc-file-setprop file 'vc-master-workfile--version nil)
        (vc-file-setprop file 'vc-master-locks nil))
      (progn
        (vc-file-setprop file 'vc-cvs-status nil))))
@@ -254,7 +254,8 @@
 	     (string= (vc-file-getprop file 'vc-head-version)
 		      workfile-version))
 	 ;; If we are not on the trunk, we need to examine the
 	 ;; whole current branch.  (vc-top-version is not what we need.)
 	 (save-excursion
 	   (set-buffer (get-buffer-create "*vc-info*"))
 	   (vc-insert-file (vc-name file) "^desc")
@@ -254,7 +254,8 @@
 		      workfile-version))
 	 ;; If we are not on the trunk, we need to examine the
-	 ;; whole current branch.  (vc-top-version is not what we need.)
+	 ;; whole current branch.  (vc-master-workfile-version 
+         ;; is not what we need.)
 	 (save-excursion
 	   (set-buffer (get-buffer-create "*vc-info*"))